--- C:/Users/SplitIce/Dropbox/Projects/X4B/NginxBuild/nginx-orig/src/http/ngx_http_upstream.c	Tue Nov 19 20:33:48 2013
+++ C:/Users/SplitIce/Dropbox/Projects/X4B/NginxBuild/nginx/src/http/ngx_http_upstream.c	Sat Nov 23 11:57:08 2013
@@ -133,6 +133,8 @@
 #endif
 
 static ngx_int_t ngx_http_upstream_add_variables(ngx_conf_t *cf);
+static ngx_int_t ngx_http_upstream_connecting_variable(ngx_http_request_t *r,
+    ngx_http_variable_value_t *v, uintptr_t data);
 static ngx_int_t ngx_http_upstream_addr_variable(ngx_http_request_t *r,
     ngx_http_variable_value_t *v, uintptr_t data);
 static ngx_int_t ngx_http_upstream_status_variable(ngx_http_request_t *r,
@@ -342,6 +344,10 @@
       ngx_http_upstream_addr_variable, 0,
       NGX_HTTP_VAR_NOCACHEABLE, 0 },
 
+    { ngx_string("upstream_connecting"), NULL,
+      ngx_http_upstream_connecting_variable, 0,
+      NGX_HTTP_VAR_NOCACHEABLE, 0 },
+
     { ngx_string("upstream_status"), NULL,
       ngx_http_upstream_status_variable, 0,
       NGX_HTTP_VAR_NOCACHEABLE, 0 },
@@ -534,7 +540,7 @@
         return;
     }
 
-    u->peer.local = ngx_http_upstream_get_local(r, u->conf->local);
+    u->peer.local = NULL;
 
     clcf = ngx_http_get_module_loc_conf(r, ngx_http_core_module);
 
@@ -594,6 +600,8 @@
                 return;
             }
 
+            u->peer.local = ngx_http_upstream_get_local(r, u->conf->local);
+
             ngx_http_upstream_connect(r, u);
 
             return;
@@ -677,6 +685,8 @@
         return;
     }
 
+    u->peer.local = ngx_http_upstream_get_local(r, u->conf->local);
+
     ngx_http_upstream_connect(r, u);
 }
 
@@ -4239,6 +4249,46 @@
         var->get_handler = v->get_handler;
         var->data = v->data;
     }
+
+    return NGX_OK;
+}
+
+static ngx_int_t
+ngx_http_upstream_connecting_variable(ngx_http_request_t *r,
+    ngx_http_variable_value_t *v, uintptr_t data)
+{
+    u_char                     *p;
+    size_t                      len;
+    ngx_int_t                   rc;
+
+    v->valid = 1;
+    v->no_cacheable = 0;
+    v->not_found = 0;
+
+    if (r->upstream->peer.sockaddr == NULL) {
+        rc = r->upstream->peer.get(&r->upstream->peer, r->upstream->peer.data);
+        if (rc != NGX_OK || r->upstream->peer.sockaddr == NULL) {
+            p = ngx_pnalloc(r->pool, 1);
+            *p = '-';
+            v->data = p;
+            v->len = 1;
+            return NGX_OK;
+        }
+    }
+
+    len = r->upstream->peer.name->len;
+
+
+    p = ngx_pnalloc(r->pool, len);
+    if (p == NULL) {
+        return NGX_ERROR;
+    }
+
+    v->data = p;
+
+    p = ngx_cpymem(p, r->upstream->peer.name->data, len);
+
+    v->len = len;
 
     return NGX_OK;
 }
--- C:/Users/SplitIce/Dropbox/Projects/X4B/NginxBuild/nginx-orig/src/event/ngx_event_connect.c	Tue Nov 19 20:33:48 2013
+++ C:/Users/SplitIce/Dropbox/Projects/X4B/NginxBuild/nginx/src/event/ngx_event_connect.c	Sat Nov 23 10:58:45 2013
@@ -22,9 +22,11 @@
     ngx_event_t       *rev, *wev;
     ngx_connection_t  *c;
 
-    rc = pc->get(pc, pc->data);
-    if (rc != NGX_OK) {
-        return rc;
+    if (pc->sockaddr == NULL) {
+        rc = pc->get(pc, pc->data);
+        if (rc != NGX_OK) {
+            return rc;
+        }
     }
 
     s = ngx_socket(pc->sockaddr->sa_family, SOCK_STREAM, 0);
